#!/usr/bin/python
#
# GUI for RHN Registration
# Copyright (c) 2000 Red Hat, Inc.
#
# Author: Preston Brown <pbrown@redhat.com>


from socket import gethostname
from os import geteuid, chdir
import sys
import string

saveargs = []
for arg in sys.argv[1:]:
    saveargs.append(arg)
    sys.argv.remove(arg)

import gtk, GTK
from gtk import TRUE
from gtk import FALSE
import GDK
import gnome
import gnome.ui
import libglade
import signal

sys.path.append("/usr/share/rhn/register")

import progress
import checklist
import rhnreg, hardware

from translate import _, N_, cat

class Gui:

    def __init__(self):
        self.test = FALSE
        self.running = FALSE
        self.initPrivacy = FALSE
        self.initPackages = FALSE
        self.initProfile = FALSE
        self.lastRow = -1
        self.xml = libglade.GladeXML("/usr/share/rhn/register/gui.glade",
                                     "mainWin")
        
        # set up signal/slot connections
        self.xml.signal_autoconnect (
            { "onDruidCancel" : self.onDruidCancel,
              "onPrivacyPagePrepare": self.onPrivacyPagePrepare,
              "onInfoPagePrepare" : self.onInfoPagePrepare,
              "onInfoPageNext" : self.onInfoPageNext,
              "onEnableNotifyButtonToggled" : self.buttonToggled,
              "onProductPagePrepare" : self.onProductPagePrepare,
              "onProductPageNext" : self.onProductPageNext,
              "onProfilePagePrepare" : self.onProfilePagePrepare,
              "onProfilePageNext" : self.onProfilePageNext,
              "onProfilePageBack" : self.onProfilePageBack,
              "onEnableHardwareButtonToggled" : self.onEnableHardwareButtonToggled,
              "onPackagePagePrepare" : self.onPackagePagePrepare,
              "onEnableRpmButtonToggled" : self.onEnableRpmButtonToggled,
              "onSendPageBack" : self.onSendPageBack,
              "onSendPageNext" : self.onSendPageNext,
              "onFinishPagePrepare" : self.onFinishPagePrepare,
              "onFinishPageFinish" : self.onFinishPageFinish })

        sp = self.xml.get_widget("startPage")
        self.mainWin = self.xml.get_widget("mainWin")                
        self.mainWin.connect("delete-event", gtk.mainquit)
        self.mainWin.connect("hide", gtk.mainquit)

        window = self.xml.get_widget("packageWindow")
        self.packageArea = checklist.CheckList(3)
        self.packageArea.set_column_title(1, _("Package Name"))
        self.packageArea.set_column_min_width(1, 200)
        self.packageArea.set_column_title(2, _("Version"))
        self.packageArea.set_column_title(3, _("Release"))
        self.packageArea.column_titles_show()
        #self.packageArea.connect("select_row", self.showPackageInfo)

        window.add(self.packageArea)
        window.show_all()
        
        self.setBusyCursor()
        try:
            sp.set_text(rhnreg.welcomeText())
        except rhnreg.CommunicationError, e:
            self.fatalError(_("Fatal error retrieving welcome message: ") + e.errmsg)
        self.setArrowCursor()
        self.running = TRUE


    def onDruidCancel(self, dummy):
        gtk.mainquit()
        sys.exit(2)


    def buttonToggled(self, button):
        if button.get_name() == "enableNotifyButton" :
            self.xml.get_widget("emailLabel").set_sensitive(button.get_active())
            self.xml.get_widget("emailEntry").set_sensitive(button.get_active())
        else:
            print _("unhandled button %s") % button.get_name()

    def fatalError(self, error):
        self.setArrowCursor()
        dlg = gnome.ui.GnomeErrorDialog(error, self.mainWin)
        dlg.show_all()
        dlg.run_and_close()
        
        if self.running:
            gtk.mainquit()
        sys.exit(1)


    def setBusyCursor(self):
        cursor = gtk.cursor_new (GDK.WATCH)
        self.mainWin.get_window().set_cursor(cursor)
        while gtk.events_pending():
            gtk.mainiteration(FALSE)


    def setArrowCursor(self):
        cursor = gtk.cursor_new (GDK.LEFT_PTR)
        self.mainWin.get_window().set_cursor(cursor)
        while gtk.events_pending():
            gtk.mainiteration(FALSE)

    
    def onPrivacyPagePrepare(self, page, dummy):
        if not self.initPrivacy:
            self.setBusyCursor()

            privacyArea = self.xml.get_widget("privacyArea")
            privacyArea.delete_text(0, privacyArea.get_length())
            try:
                text = rhnreg.privacyText()
            except rhnreg.CommunicationError, e:
                self.mainWin.hide()
                self.fatalError(_("Fatal error retrieving privacy statement: ") + e.errmsg)
            
            privacyArea.insert_defaults(text)
            self.initPrivacy = TRUE
            self.setArrowCursor()
            

    def onInfoPagePrepare(self, page, dummy):
        entry = self.xml.get_widget("emailEntry")
        cb = self.xml.get_widget("enableNotifyButton")
        self.xml.get_widget("emailLabel").set_sensitive(cb.get_active())
        self.xml.get_widget("emailEntry").set_sensitive(cb.get_active())


    def onInfoPageNext(self, page, dummy):
        pw1 = self.xml.get_widget("passwordEntry")
        pw2 = self.xml.get_widget("password2Entry")
        uname = self.xml.get_widget("usernameEntry")
        druid = self.xml.get_widget("druid")

        self.setBusyCursor()
        
        # validate / check user name
        if uname.get_text() == "":
            self.setArrowCursor()
            dlg = gnome.ui.GnomeErrorDialog(_("You must enter a user name."),
                                            self.mainWin)
            uname.grab_focus()
            return TRUE
        if pw1.get_text() == "" or pw2.get_text() == "":
            self.setArrowCursor()
            dlg = gnome.ui.GnomeErrorDialog(_("You must enter and verify a password."),
                                            self.mainWin)
            pw1.grab_focus()
            return TRUE

        if not pw1.get_text() == pw2.get_text():
            self.setArrowCursor()
            dlg = gnome.ui.GnomeErrorDialog(_("The two passwords you entered do not match.\nPlease re-type the second password."), self.mainWin)
            pw2.set_text("")
            pw2.grab_focus()
            return TRUE


        try:
            rhnreg.reserveUser(uname.get_text(), pw1.get_text())
        except rhnreg.ValidationError, e:
            self.setArrowCursor()
            dlg = gnome.ui.GnomeErrorDialog(_("The server indicated an error:\n") + e.errmsg,
                                            self.mainWin)
            uname.grab_focus()
            return TRUE
        except rhnreg.CommunicationError, e:
            self.setArrowCursor()
            self.fatalError(_("There was an error communicating with the registration server.  The message was:\n") + e.errmsg)
            
        if self.xml.get_widget("enableNotifyButton").get_active():
            entry = self.xml.get_widget("emailEntry")
            if not rhnreg.validateEmail(entry.get_text()):
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a valid email address."), self.mainWin)
                entry.set_text("")
                entry.grab_focus()
                return TRUE

        druid = self.xml.get_widget("druid")
        if self.xml.get_widget("regNumEntry").get_text() != "":
            if not self.xml.get_widget("enableNotifyButton").get_active():
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enable e-mail notification and provide a valid email address\nif you are registering a product."))
                self.xml.get_widget("enableNotifyButton").set_active(TRUE)
                self.xml.get_widget("emailEntry").grab_focus()
                return TRUE
            else:
                try:
                    rhnreg.validateRegNum(self.xml.get_widget("regNumEntry").get_text())
                except rhnreg.ValidationError, e:
                    self.setArrowCursor()
                    dlg = gnome.ui.GnomeErrorDialog(e.errmsg,
                                                    self.mainWin)
                    self.xml.get_widget("regNumEntry").grab_focus()
                    return TRUE
                except rhnreg.CommunicationError, e:
                    self.setArrowCursor()
                    self.fatalError(_("There was an error communicating with the registration server.  The message was:\n") + e.errmsg)
                
        self.setArrowCursor()
        return FALSE


    def onProductPagePrepare(self, page, dummy):
        self.setBusyCursor()

        if not self.xml.get_widget("enableNotifyButton").get_active():
            self.xml.get_widget("emailContactButton").set_sensitive(FALSE)
            self.xml.get_widget("emailContactButton").set_active(FALSE)
            self.xml.get_widget("specialContactButton").set_sensitive(FALSE)
            self.xml.get_widget("specialContactButton").set_active(FALSE)
            self.xml.get_widget("utbContactButton").set_sensitive(FALSE)
            self.xml.get_widget("utbContactButton").set_active(FALSE)
        else:
            self.xml.get_widget("emailContactButton").set_sensitive(TRUE)
            self.xml.get_widget("specialContactButton").set_sensitive(TRUE)
            self.xml.get_widget("utbContactButton").set_sensitive(TRUE)
            
        label = self.xml.get_widget("regNumLabel2")
        entry = self.xml.get_widget("regNumEntry")            
        if entry.get_text() == "":
            self.xml.get_widget("regInfoLabel").set_text(_("All information is optional."))
            self.xml.get_widget("redLabel").hide()
            label.set_text("")

            label = self.xml.get_widget("redLabel")
            style = label.get_style().copy()
            label = self.xml.get_widget("firstNameLabel")
            label.set_style(style)
            label = self.xml.get_widget("lastNameLabel")
            label.set_style(style)
            label = self.xml.get_widget("address1Label")
            label.set_style(style)
            label = self.xml.get_widget("cityLabel")
            label.set_style(style)
            label = self.xml.get_widget("stateLabel")
            label.set_style(style)
            label = self.xml.get_widget("zipLabel")
            label.set_style(style)
            label = self.xml.get_widget("countryLabel")
            label.set_style(style)
            label = self.xml.get_widget("phoneLabel")
            label.set_style(style)
        else:
            self.xml.get_widget("regInfoLabel").set_text(_("Registration information for: "))
            self.xml.get_widget("regInfoLabel").show()
            self.xml.get_widget("redLabel").show()
            label.set_text(entry.get_text())

            color = gtk.GdkColor(65000,0,0)
            label = self.xml.get_widget("titleLabel")
            style = label.get_style().copy()
            style.fg[GTK.STATE_NORMAL] = color
            label.set_style(style)
            label = self.xml.get_widget("firstNameLabel")
            label.set_style(style)
            label = self.xml.get_widget("lastNameLabel")
            label.set_style(style)
            label = self.xml.get_widget("address1Label")
            label.set_style(style)
            label = self.xml.get_widget("cityLabel")
            label.set_style(style)
            label = self.xml.get_widget("stateLabel")
            label.set_style(style)
            label = self.xml.get_widget("zipLabel")
            label.set_style(style)
            label = self.xml.get_widget("countryLabel")
            label.set_style(style)
            label = self.xml.get_widget("phoneLabel")
            label.set_style(style)

        self.setArrowCursor()

        
    def onProductPageNext(self, page, dummy):
        self.productInfo = {}
        self.setBusyCursor()

        self.productInfo['reg_num'] = self.xml.get_widget("regNumEntry").get_text()
        self.productInfo['title'] = self.xml.get_widget("titleCombo").entry.get_text()
        entry = self.xml.get_widget("firstNameEntry")

        if self.xml.get_widget("regNumEntry").get_text() != "":
            if entry.get_text() == "":
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a first name."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['first_name'] = entry.get_text()

        entry = self.xml.get_widget("lastNameEntry")
        if self.xml.get_widget("regNumEntry").get_text() != "":
            if entry.get_text() == "":
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a last name."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['last_name'] = entry.get_text()

        self.productInfo['company'] = self.xml.get_widget("companyEntry").get_text()

        self.productInfo['position'] = self.xml.get_widget("positionEntry").get_text()

        entry = self.xml.get_widget("address1Entry")
        if self.xml.get_widget("regNumEntry").get_text() != "":
            if entry.get_text() == "":
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter an address."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['address1'] = entry.get_text()
        
        self.productInfo['address2'] = self.xml.get_widget("address2Entry").get_text()

        entry = self.xml.get_widget("cityEntry")
        if self.xml.get_widget("regNumEntry").get_text() != "":        
            if entry.get_text() == "":
                self.setArrowCursor()        
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a city."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['city'] = entry.get_text()

        entry = self.xml.get_widget("stateCombo").entry
        if self.xml.get_widget("regNumEntry").get_text() != "":        
            if entry.get_text() == "":
                self.setArrowCursor()        
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a state or province."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['state'] = entry.get_text()

        entry = self.xml.get_widget("zipEntry")
        if self.xml.get_widget("regNumEntry").get_text() != "":
            if entry.get_text() == "":
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a zip or postal code."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['zip'] = entry.get_text()

        entry = self.xml.get_widget("countryCombo").entry
        if self.xml.get_widget("regNumEntry").get_text() != "":        
            if entry.get_text() == "":
                self.setArrowCursor()        
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a country."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['country'] = entry.get_text()

        entry = self.xml.get_widget("phoneEntry")
        if self.xml.get_widget("regNumEntry").get_text() != "":
            if entry.get_text() == "":
                self.setArrowCursor()
                dlg = gnome.ui.GnomeErrorDialog(_("You must enter a phone number."), self.mainWin)
                entry.grab_focus()
                return TRUE

        self.productInfo['phone'] = entry.get_text()


        self.productInfo['fax'] = self.xml.get_widget("faxEntry").get_text()

        button = self.xml.get_widget("emailContactButton")
        if button.get_active():
            self.productInfo['contact_email'] = 1
        else:
            self.productInfo['contact_email'] = 0

        button = self.xml.get_widget("mailContactButton")
        if button.get_active():
            self.productInfo['contact_mail'] = 1
        else:
            self.productInfo['contact_mail'] = 0

        button = self.xml.get_widget("phoneContactButton")
        if button.get_active():
            self.productInfo['contact_phone'] = 1
        else:
            self.productInfo['contact_phone'] = 0

        button = self.xml.get_widget("utbContactButton")
        if button.get_active():
            self.productInfo['newsletter'] = 1
        else:
            self.productInfo['newsletter'] = 0

        button = self.xml.get_widget("specialContactButton")
        if button.get_active():
            self.productInfo['special_offers'] = 1
        else:
            self.productInfo['special_offers'] = 0

        # in the optional case fix up fields that had default choices:
        if self.xml.get_widget("firstNameEntry").get_text() == "":
            self.productInfo['title'] = ""
            self.productInfo['state'] = ""
            self.productInfo['country'] = ""
            
        self.setArrowCursor()
        
            
    def onProfilePagePrepare(self, page, dummy):
        self.sendHardware = self.xml.get_widget("enableHardwareButton").get_active()
        
        if not self.initProfile:
            hostname = gethostname()

            if string.find(hostname, "localhost") == -1:
                self.xml.get_widget("profileNameEntry").set_text(hostname)

            hardware.read_kudzu()
            hardware.read_cpuinfo()
            hardware.read_memory()
            hardware.read_network()
            self.hardware = hardware.Hardware
            
            for hw in hardware.Hardware:
                if hw['class'] == 'CPU':
                    label = self.xml.get_widget("cpuLabel")
                    label.set_text(hw['model'])
                    label.hide()
                    label.show()
                    label = self.xml.get_widget("speedLabel")
                    label.set_text(_("%d MHz") % hw['speed'])
                    label.hide()
                    label.show()
                elif hw['class'] == 'MEMORY':
                    label = self.xml.get_widget("ramLabel")
                    try:
                        label.set_text(_("%s megabytes") % hw['ram'])
                    except:
                        pass
                    label.hide()
                    label.show()

                elif hw['class'] == 'NETINFO':
                    label = self.xml.get_widget("hostnameLabel")
                    try:
                        label.set_text(hw['hostname'])
                    except:
                        pass
                    label.hide()
                    label.show()
                    label = self.xml.get_widget("ipLabel")
                    try:
                        label.set_text(hw['ipaddr'])
                    except:
                        pass
                    label.hide()
                    label.show()

            label = self.xml.get_widget("versionLabel")
            label.set_text(rhnreg.getVersion())
            label.hide()
            label.show()

            self.initProfile = TRUE
        
        
    def onProfilePageNext(self, page, dummy):
        if self.xml.get_widget("profileNameEntry").get_text() == "":
            dlg = gnome.ui.GnomeErrorDialog(_("You must choose a name for this profile."), self.mainWin)
            self.xml.get_widget("profileNameEntry").grab_focus()
            return TRUE
        
        return FALSE


    def onProfilePageBack(self, page, dummy):
        return FALSE
    
        #druid = self.xml.get_widget("druid")
        #if self.xml.get_widget("regNumEntry").get_text() != "":
        #    druid.set_page(self.xml.get_widget("productPage"))
        #else:
        #    druid.set_page(self.xml.get_widget("infoPage"))
        #
        #return TRUE
                               

    def onEnableHardwareButtonToggled(self, button):
        self.sendHardware = button.get_active()
        
        if not self.sendHardware:
            self.xml.get_widget("hostnameTag").hide()
            self.xml.get_widget("hostnameLabel").hide()
            self.xml.get_widget("ipTag").hide()
            self.xml.get_widget("ipLabel").hide()
            self.xml.get_widget("cpuTag").hide()
            self.xml.get_widget("cpuLabel").hide()
            self.xml.get_widget("speedTag").hide()
            self.xml.get_widget("speedLabel").hide()
            self.xml.get_widget("ramTag").hide()
            self.xml.get_widget("ramLabel").hide()
            self.xml.get_widget("hwNoteLabel").hide()
        else:
            self.xml.get_widget("hostnameTag").show()
            self.xml.get_widget("hostnameLabel").show()
            self.xml.get_widget("ipTag").show()
            self.xml.get_widget("ipLabel").show()
            self.xml.get_widget("cpuTag").show()
            self.xml.get_widget("cpuLabel").show()
            self.xml.get_widget("speedTag").show()
            self.xml.get_widget("speedLabel").show()
            self.xml.get_widget("ramTag").show()
            self.xml.get_widget("ramLabel").show()
            self.xml.get_widget("hwNoteLabel").show()
                    
    
    def onPackagePagePrepare(self, page, dummy):
        self.sendPackages = self.xml.get_widget("enableRpmButton").get_active()
        
        if not self.initPackages:
            self.setBusyCursor()
            pwin = progress.Progress()
            pwin.setLabel(_("The Registration Wizard is building a list of RPM packages installed on your system.  Please wait."))

            packages = rhnreg.buildPackageList(pwin.setProgress)
            pwin.hide()

            for package in packages:
                self.packageArea.append_row((package[0], package[1], package[2]),
                                            TRUE, package[0])

            self.initPackages = TRUE
            self.setArrowCursor()


    def onEnableRpmButtonToggled(self, button):
        self.sendPackages = button.get_active()

        if not self.sendPackages:
            self.packageArea.set_sensitive(FALSE)
            self.xml.get_widget("packageLabel").set_sensitive(FALSE)
            self.xml.get_widget("packageNoteLabel").hide()
            pass
        else:
            self.packageArea.set_sensitive(TRUE)
            self.xml.get_widget("packageLabel").set_sensitive(FALSE)
            self.xml.get_widget("packageNoteLabel").show()
            pass

    def onSendPageBack(self, page, dummy):
        return FALSE


    def onSendPageNext(self, page, dummy):
        self.setBusyCursor()

        pwin = progress.Progress()
        pwin.setLabel(_("Sending your profile information to Red Hat Network.  Please wait."))
        username = self.xml.get_widget("usernameEntry").get_text()
        password = self.xml.get_widget("passwordEntry").get_text()
        if self.xml.get_widget("enableNotifyButton").get_active():
            email = self.xml.get_widget("emailEntry").get_text()
        else:
            email = None
        profileName = self.xml.get_widget("profileNameEntry").get_text()

        try:
            rhnreg.registerUser(username, password, email)
        except:
            self.setArrowCursor()
            pwin.hide()
            dlg = gnome.ui.GnomeErrorDialog(_("Problem registering username."),
                                            self.mainWin)
            return TRUE

        pwin.setProgress(1, 6)

        try:
            systemId = rhnreg.registerSystem(username, password, profileName)
        except:
            self.setArrowCursor()
            pwin.hide()
            dlg = gnome.ui.GnomeErrorDialog(_("Problem registering system."),
                                            self.mainWin)
            return TRUE

        pwin.setProgress(2, 6)

        # write the system id out.
        if not rhnreg.writeSystemId(systemId):
            self.setArrowCursor()
            pwin.hide()
            dlg = gnome.ui.GnomeErrorDialog(_("Problem writing out system id to disk."),
                                            self.mainWin)
            return TRUE

        # maybe send product registration information
        if self.xml.get_widget("firstNameEntry").get_text() != "":
            try:
                rhnreg.registerProduct(systemId, self.productInfo)
            except:
                self.setArrowCursor()
                pwin.hide()
                dlg = gnome.ui.GnomeErrorDialog(_("Problem registering your product."),
                                                self.mainWin)
                return TRUE

        pwin.setProgress(3, 6)
            
        # maybe upload hardware profile
        if self.sendHardware:
            try:
                rhnreg.sendHardware(systemId, self.hardware)
            except:
                self.setArrowCursor()
                pwin.hide()
                dlg = gnome.ui.GnomeErrorDialog(_("Problem sending hardware profile."),
                                                self.mainWin)
                return TRUE

        pwin.setProgress(4, 6)
        
        # build up package list if necessary
        if self.sendPackages:

            packageList = rhnreg.buildPackageList(lambda amount, total: gtk.mainiteration(FALSE))
            selection = []
            for row in range(self.packageArea.n_rows):
                rowData = self.packageArea.get_row_data(row)
                if rowData[0] == 1:
                    selection.append(rowData[1])

            selectedPackages = []
            for pkg in packageList:
                if pkg[0] in selection:
                    selectedPackages.append(pkg)

            try:
                rhnreg.sendPackages(systemId, selectedPackages)
            except:
                self.setArrowCursor()
                pwin.hide()
                dlg = gnome.ui.GnomeErrorDialog(_("Problem sending packages."),
                                                self.mainWin)
                return TRUE

        pwin.setProgress(5, 6)
        pwin.hide()
        
        self.setArrowCursor()
        return FALSE


    def onFinishPagePrepare(self, page, dummy):
        druid = self.xml.get_widget("druid")
        druid.set_buttons_sensitive(FALSE, TRUE, FALSE)
        return FALSE


    def onFinishPageFinish(self, page, dummy):
        gtk.mainquit()


def main():

    def cb(foo):
        return foo
        
    test = 0
    if len(saveargs) > 0:
        if saveargs[0] == "-t" or saveargs[0] == "--test":
            test = 1
        if saveargs[0] == "-a" or saveargs[0] == "--about":
            dlg = gnome.ui.GnomeAbout(_("About RHN Registration Program"),
                                      "1.0",
                                      "Copyright (c) 2000 Red Hat, Inc.",
                                      ["Preston Brown <pbrown@redhat.com>",
                                       "Cristian Gafton <gafton@redhat.com>"],
                                      _("Please Report bugs to Red Hat's Bug Tracking System: http://bugzilla.redhat.com"))
            dlg.run_and_close()
            sys.exit(0)
        
    signal.signal (signal.SIGINT, signal.SIG_DFL)

    if not rhnreg.hasSSL():
        dlg = gnome.ui.GnomeQuestionDialog(_("""Your system libraries do not support SSL (secure) connections.  Any data
that you send or receive from Red Hat Network will be transmitted in the clear.
Continue anyway?"""), cb)
        if dlg.run_and_close():
            sys.exit(1)

    if geteuid() != 0 and not test:
        dlg = gnome.ui.GnomeErrorDialog(_("You must run the Red Hat Network registration program as root."))
        dlg.run_and_close()
        sys.exit(1)

    if rhnreg.registered() and not test:
        dlg = gnome.ui.GnomeQuestionDialog(_("This system appears to already be registered.\nContinue anyway?"), cb)
        if dlg.run_and_close():
            sys.exit(1)

    gui = Gui()
        
    if test:
        gui.test = TRUE
    
    gtk.mainloop()

if __name__ == "__main__":
    main()
